# blipy

Blipy is a http requester made specifically to be used with [BLiP.ai](https://portal.blip.ai/) endpoints, with some requests right out of the box. Available endpoints can be found in [BLiP documentation](https://docs.blip.ai).

  - Instantiate requesters classes using the bot key
  - No need to request all resources manually
  - Magic

### Installation

Use `pip` to install the package.

```sh
$ pip install blipy
```

### Modules

Blipy offers the following modules.

| Modules | README |
| ------ | ------ |
| Types | Contains base types for the package |
| Http | Requesters like Lime and Postmaster |
| Postmasters | Pre configured Postmasters |

### Todos
 - Write tests
 - Add more postmasters
